--[[

        TalentSafe:
        Confirm choice when learning a talent.

        Bima, aka Tale, aka David C Lawrence <reg+wow-addons@dd.org>

]]

local L = AceLibrary("AceLocale-2.2"):new("TalentSafe")

L:RegisterTranslations("enUS", function() return {
    ["Learn"] = true,
} end)

L:RegisterTranslations("frFR", function() return {
    ["Learn"] = "Apprenez",
} end)

L:RegisterTranslations("deDE", function() return {
    ["Learn"] = "Erlernen",
} end)

TalentSafe = AceLibrary("AceAddon-2.0"):new("AceConsole-2.0", "AceEvent-2.0", 
                                            "AceDB-2.0", "AceHook-2.1")
TalentSafe.version = "2.0."..string.sub("$Revision: 25931 $", 12, -3)
TalentSafe.date = string.sub("$Date: 2007-01-23 18:43:23 -0500 (Tue, 23 Jan 2007) $", 8, 17)
TalentSafe:RegisterChatCommand({"/talentsafe"}, {type = "group", args = {}})
TalentSafe:RegisterDB("TalentSafeDB")

function TalentSafe:OnInitialize()
    self:RegisterEvent("VARIABLES_LOADED")
end

function TalentSafe:OnEnable()
    self:Hook("TalentFrameTalent_OnClick", "ConfirmClick", true)
    --self:Print("locked and loaded.")
end

function TalentSafe:OnDisable()
    --self:Print("disabled.")
end

function TalentSafe:VARIABLES_LOADED()
    if (myAddOnsFrame) then
	myAddOnsList.TalentSafe = {
	    name = "TalentSafe", 
	    description = "Confirm talent choices",
	    version = TalentSafe.version,
	    category = MYADDONS_CATEGORY_OTHERS
	}
    end
end

--- 
--- Redefines the standard Blizzard function from FrameXML/TalentFrame.lua
--- Honestly, figuring out whether a talent is learnable is more painful
--- than it should be.
--- 
function TalentSafe:ConfirmClick()
    if (TalentFrame.talentPoints < 1) then
        return
    end

    local tab = PanelTemplates_GetSelectedTab(TalentFrame)
    local talent = this:GetID()

    local name, texture, tier, column, rank, maxrank, exceptional, prereqok =
        GetTalentInfo(tab, talent)

    if (rank == maxrank) then
        return
    end

    if ((tier - 1) * 5 >  TalentFrame.pointsSpent) then 
        return
    end

    -- I have no idea how come the 8th return value from GetTalentInfo,
    -- which the standard TalentFrame.lua names "meetsPrereq", declares
    -- a true value when in fact prereqs are not met.  Furthermore,
    -- why does TalentFrame.lua process the return values from
    -- GetTalentPrereqs as though there can be more than one tuple?
    -- Is there ever more than one prereq talent for any other talent?
    local prereqs = { GetTalentPrereqs(tab, talent) }

    local i;
    for i = 1, table.getn(prereqs), 3 do
        if (not prereqs[i+2]) then
            return
        end
    end

    local ranktext
    if (maxrank > 1) then
        ranktext = " (" .. (rank + 1) .. "/" .. maxrank .. ")"
    else
        ranktext = ""
    end

    StaticPopupDialogs["TALENTSAFE"] = {
        text = L["Learn"] .. " " .. name .. ranktext .. "?",
        button1 = YES,
        button2 = NO,
        OnAccept = function()
            LearnTalent(tab, talent)
        end,
        timeout = 0,
        exclusive = 1,
        whileDead = 1,
        interruptCinematic = 1
    };
    StaticPopup_Show("TALENTSAFE");
end
